# Sources

- [List userConfigurations](https://learn.microsoft.com/en-us/graph/api/teamsadministration-teamsadminroot-list-userconfigurations?view=graph-rest-beta)
- [Get teamsUserConfiguration](https://learn.microsoft.com/en-us/graph/api/teamsadministration-teamsuserconfiguration-get?view=graph-rest-beta)
- [teamsUserConfiguration resource](https://learn.microsoft.com/en-us/graph/api/resources/teamsadministration-teamsuserconfiguration?view=graph-rest-beta)
- [List numberAssignments](https://learn.microsoft.com/en-us/graph/api/teamsadministration-telephonenumbermanagementroot-list-numberassignments?view=graph-rest-beta)
- [Get numberAssignment](https://learn.microsoft.com/en-us/graph/api/teamsadministration-numberassignment-get?view=graph-rest-beta)
- [numberAssignment resource](https://learn.microsoft.com/en-us/graph/api/resources/teamsadministration-numberassignment?view=graph-rest-beta)
- [numberAssignment: assignNumber](https://learn.microsoft.com/en-us/graph/api/teamsadministration-numberassignment-assignnumber?view=graph-rest-beta)
- [numberAssignment: unassignNumber](https://learn.microsoft.com/en-us/graph/api/teamsadministration-numberassignment-unassignnumber?view=graph-rest-beta)
- [numberAssignment: updateNumber](https://learn.microsoft.com/en-us/graph/api/teamsadministration-numberassignment-updatenumber?view=graph-rest-beta)
- [teamsPolicyUserAssignment: assign](https://learn.microsoft.com/en-us/graph/api/teamsadministration-teamspolicyuserassignment-assign?view=graph-rest-beta)
- [MC1169072 Announcement](https://m365admin.handsontek.net/microsoft-teams-microsoft-graph-apis-teams-administration-now-available-beta/)
- [Manage emergency locations](https://learn.microsoft.com/en-us/microsoftteams/add-change-remove-emergency-location-organization) (PowerShell only)
- [Get-CsOnlineLisCivicAddress](https://learn.microsoft.com/en-us/powershell/module/teams/get-csonlineliscivicaddress)
- [Get-CsOnlineLisLocation](https://learn.microsoft.com/en-us/powershell/module/teams/get-csonlinelislocation)
- [Get-CsTeamsCallingPolicy](https://learn.microsoft.com/en-us/powershell/module/teams/get-csteamscallingpolicy)
- [MicrosoftTeams PowerShell Module](https://learn.microsoft.com/en-us/microsoftteams/teams-powershell-overview)
- [telephoneNumberLongRunningOperation resource](https://learn.microsoft.com/en-us/graph/api/resources/teamsadministration-telephonenumberlongrunningoperation?view=graph-rest-beta)
- [Get telephoneNumberLongRunningOperation](https://learn.microsoft.com/en-us/graph/api/teamsadministration-telephonenumberlongrunningoperation-get?view=graph-rest-beta)
- [telephoneNumberManagementRoot resource](https://learn.microsoft.com/en-us/graph/api/resources/teamsadministration-telephonenumbermanagementroot?view=graph-rest-beta)
- [New-CsBatchPolicyAssignmentOperation (policy types)](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/new-csbatchpolicyassignmentoperation?view=teams-ps)
- [effectivePolicyAssignment resource](https://learn.microsoft.com/en-us/graph/api/resources/teamsadministration-effectivepolicyassignment?view=graph-rest-beta)
- [Manage Voicemail Policies](https://learn.microsoft.com/en-us/microsoftteams/manage-voicemail-policies)
- [JSON Batching](https://learn.microsoft.com/en-us/graph/json-batching)
- [Batch Requests with SDKs](https://learn.microsoft.com/en-us/graph/sdks/batch-requests)
- [Application-based authentication in Teams PowerShell](https://learn.microsoft.com/en-us/microsoftteams/teams-powershell-application-authentication)
- [Connect-MicrosoftTeams cmdlet](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/connect-microsoftteams?view=teams-ps)
- [Teams PowerShell Overview](https://learn.microsoft.com/en-us/microsoftteams/teams-powershell-overview)
- [Install Microsoft Teams PowerShell Module](https://learn.microsoft.com/en-us/microsoftteams/teams-powershell-install)
- [New-CsOnlineLisLocation](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/new-csonlinelislocation?view=teams-ps)
- [New-CsOnlineLisCivicAddress](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/new-csonlineliscivicaddress?view=teams-ps)
- [Get-CsOnlineVoicemailPolicy](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/get-csonlinevoicemailpolicy?view=teams-ps)
- [Get-CsCallingLineIdentity](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/get-cscallinglineidentity?view=teams-ps)
- [Get-CsTenantDialPlan](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/get-cstenantdialplan?view=teams-ps)
- [Get-CsOnlineVoiceRoutingPolicy](https://learn.microsoft.com/en-us/powershell/module/teams/get-csonlinevoiceroutingpolicy?view=teams-ps)
- [Get-CsTeamsEmergencyCallingPolicy](https://learn.microsoft.com/en-us/powershell/module/teams/get-csteamsemergencycallingpolicy?view=teams-ps)
- [Get-CsTeamsEmergencyCallRoutingPolicy](https://learn.microsoft.com/en-us/powershell/module/microsoftteams/get-csteamsemergencycallroutingpolicy?view=teams-ps)
